Breakpoint class

A representation of a screen size breakpoint.

Constructors

Breakpoint(double value, double scaleValue)
Creates a new Breakpoint instance with a width threshold value and an associated scaling multiplier scaleValue.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale Scale
The scaling factor associated with this breakpoint.
final
value double
The width threshold value.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited