Breakpoint class
A representation of a screen size breakpoint.
Constructors
- Breakpoint(double value, double scaleValue)
-
Creates a new Breakpoint instance with a width threshold
valueand an associated scaling multiplierscaleValue.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited